@@ -1,5 +1,5 @@
 /*
- * $Id: syscfg.h,v 1.28 2004/04/13 17:24:01 broeker Exp $
+ * $Id: syscfg.h,v 1.33 2006/03/06 17:42:29 broeker Exp $
  */
 
 /* GNUPLOT - syscfg.h */
@@ -58,7 +58,7 @@
  * DIRSEP1:  ['/'] Primary character which separates path components.
  * DIRSEP2:  ['\0'] Secondary character which separates path components.
  * PATHSEP:  [':'] Character which separates path names
- *        
+ *
  */
 
 #if defined(AMIGA_SC_6_1) || defined(AMIGA_AC_5) || defined(__amigaos__)
@@ -121,6 +121,7 @@
 # define SHELL    "c:\\os2\\cmd.exe"
 # define DIRSEP1  '\\'
 # define PATHSEP  ';'
+# define GNUPLOT_HISTORY_FILE "~\\gnuplot_history"
 #endif /* OS/2 */
 
 #ifdef OSK
@@ -172,6 +173,7 @@
 # define SHELL   "\\command.com"
 # define DIRSEP1 '\\'
 # define PATHSEP ';'
+# define GNUPLOT_HISTORY_FILE "~\\gnuplot_history"
 #endif /* _WINDOWS */
 
 #if defined(MSDOS) && !defined(_Windows)
@@ -193,12 +195,17 @@
 # ifdef __DJGPP__
 #  define DIRSEP2 '/'
 # endif
+# define GNUPLOT_HISTORY_FILE "~\\gnuplot.his"
 #endif /* MSDOS */
 
 /* End OS dependent constants; fall-through defaults
  * for the constants defined above are following.
  */
 
+#ifndef OS
+# define OS "non-recognized OS"
+#endif
+
 #ifndef HELPFILE
 # define HELPFILE "docs/gnuplot.gih"
 #endif
@@ -301,7 +308,9 @@
  */
 #ifdef __WATCOMC__
 # include <direct.h>
+# include <dos.h>
 # define HAVE_GETCWD 1
+# define GP_EXCEPTION_NAME _exception
 #endif
 
 
@@ -351,7 +360,7 @@ typedef double coordval;
 #ifdef DOS16
 # define MAX_NUM_VAR	3
 #else
-# define MAX_NUM_VAR	5
+# define MAX_NUM_VAR	12
 #endif
 
 /* HBB 20010223: Moved VERYLARGE definition to stdfn.h: it can only be
